@@ -67,6 +67,17 @@ getYLabs <- function(p) {
   origlabs
 }
 
+# get the x lables from a ready to go ggplot2
+getXLabs <- function(p) {
+  info <- ggplot2::ggplot_build(p)
+  origlabs <- info$panel$ranges[[1]]$x.labels  # worked prior to ggplot2.2.0
+  if(!is.null(origlabs)) {
+    return(origlabs)
+  }
+  origlabs <- info$layout$panel_ranges[[1]]$x.labels
+  origlabs
+}
+
 # assumes p1 and p2 have not set scale_y_*
 designYLabelPadFunction <- function(p1,p2) {
   origlabs1 <- getYLabs(p1)
